Tuple Packing and Unpacking
:::::::::::::::::::::::::::

.. toctree::
   :caption: Tuple Packing and Unpacking
   :maxdepth: 2

   TuplePacking-Intro.rst
   TuplePacking.rst
   TupleAssignmentwithunpacking.rst
   TuplesasReturnValues.rst
   UnpackingArgumentsToFunctions.rst
   Glossary.rst
   Exercises.rst
   ChapterAssessment.rst
   